# sforecast

A framework for running forecasting models within a sliding (expanding) window out-of-sample fit (train/test) and prediction (forecasts). The package includes support of classical forecasting models, SK Learn ML models, and TensorFlow deep learning models.

## Installation

```bash
$ pip install sforecast
```

## License

`sforecast` was created by Alberto Gutierrez. It is licensed under the terms of the MIT license.

## Credits

`sforecast` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).
